pub struct ActivationAck(Arc<AtomicBool>);Expand description
Handle held by the Timely operator to acknowledge activations from a ArcActivator.
Call ActivationAck::ack at the start of each operator scheduling to allow the
ArcActivator to send new activations.
Tuple Fields
0: Arc<AtomicBool>Implementations
Sourceimpl ActivationAck
impl ActivationAck
Sourcepub fn ack(&self)
pub fn ack(&self)
Acknowledge the activation, allowing the ArcActivator to activate again.
Call this at the start of each operator scheduling.