ActivatorTrait

Trait ActivatorTrait 

pub trait ActivatorTrait {
    // Required methods
    fn activate(&self);
    fn ack(&self);
    fn register<'scope, T: Timestamp>(
        &self,
        scope: Scope<'scope, T>,
        path: Rc<[usize]>,
    );
}
Generic activator behavior

Required Methods

fn activate(&self)

Trigger an activation of operators behind this activator.

fn ack(&self)

Acknowledge the receipt of activations from within an operator.

fn register<'scope, T: Timestamp>( &self, scope: Scope<'scope, T>, path: Rc<[usize]>, )

Register a new operator with its path with this activator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors