OutputIndex

Trait OutputIndex 

pub trait OutputIndex {
    // Required method
    fn index(&self) -> usize;
}
A helper trait abstracting over an output handle. It facilitates passing type erased output handles during operator construction. It is not meant to be implemented by users.

Required Methods

fn index(&self) -> usize

The output index of this handle.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors