pub struct ColumnationChunker<T: Columnation> {
pending: Vec<T>,
ready: VecDeque<ColumnationStack<T>>,
empty: Option<ColumnationStack<T>>,
}Expand description
Chunk a stream of vectors into chains of columnation stacks.
This chunker accumulates into a Vec (not a ColumnationStack) for efficient
in-place sorting and consolidation, then copies the consolidated results
into ColumnationStack chunks. This avoids the cost of sorting through
columnation indirection.
Fields
pending: Vec<T>ready: VecDeque<ColumnationStack<T>>empty: Option<ColumnationStack<T>>Implementations
Sourceimpl<D, T, R> ColumnationChunker<(D, T, R)>
impl<D, T, R> ColumnationChunker<(D, T, R)>
const BUFFER_SIZE_BYTES: usize
fn chunk_capacity() -> usize
fn form_chunk(&mut self)