pub fn register(registry: &MetricsRegistry)Expand description
Install the buffer-pool metrics and the columnar chunk work counters into
registry. Idempotent. Repeated calls after the first one are no-ops.
pub fn register(registry: &MetricsRegistry)Install the buffer-pool metrics and the columnar chunk work counters into
registry. Idempotent. Repeated calls after the first one are no-ops.