source

Function source 

pub fn source<'scope, T>(
    scope: Scope<'scope, T>,
    name: String,
    handle: Handle<T>,
) -> StreamVec<'scope, T, Infallible>
where T: Timestamp,
Creates a stream that flows progress updates from a probe.

The returned stream is guaranteed to never yield any data updates, as is reflected by its type.