MzReplay

Trait MzReplay 

pub trait MzReplay<T, C, A>: Sized{
    // Required method
    fn mz_replay<'scope>(
        self,
        scope: Scope<'scope, T>,
        name: &str,
        period: Duration,
        activator: A,
    ) -> (Stream<'scope, T, C>, Rc<dyn Any>);
}
Replay a capture stream into a scope with the same timestamp.

Required Methods

fn mz_replay<'scope>( self, scope: Scope<'scope, T>, name: &str, period: Duration, activator: A, ) -> (Stream<'scope, T, C>, Rc<dyn Any>)

Replays self into the provided scope, as a Stream<S, CB::Container> and provides a cancellation token. Uses the supplied container builder CB to form containers.

The period argument allows the specification of a re-activation period, where the operator will re-activate itself every so often.

  • scope: The Scope to replay into.
  • name: Human-readable debug name of the Timely operator.
  • period: Reschedule the operator once the period has elapsed. Provide Duration::MAX to disable periodic scheduling.
  • activator: An activator to trigger the operator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, C, I, A> MzReplay<T, C, A> for I
where T: Timestamp, C: Container + Clone, I: IntoIterator, I::Item: EventIterator<T, C> + 'static, A: ActivatorTrait + 'static,