ScopeExt

Trait ScopeExt 

pub trait ScopeExt: Sized {
    // Required method
    fn with_label(self) -> Self;
}
Extension trait for timely Scope that allows one to convert a scope into one that sets its name as a profiling label before scheduling its child operators.

Required Methods

fn with_label(self) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'scope, T: Timestamp> ScopeExt for Scope<'scope, T>

Source

fn with_label(self) -> Self

Implementors