pub trait BucketTimestamp: Timestamp {
const DOMAIN: usize = _;
// Required method
fn advance_by_power_of_two(&self, exponent: u32) -> Option<Self>;
}Expand description
Timestamp extension for timestamps that can advance by 2^exponent.
Most likely, this is only relevant for totally ordered timestamps.
Provided Associated Constants
Required Methods
Sourcefn advance_by_power_of_two(&self, exponent: u32) -> Option<Self>
fn advance_by_power_of_two(&self, exponent: u32) -> Option<Self>
Advance this timestamp by 2^exponent. Returns None if the
timestamp would overflow.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".